@@ -2,13 +2,14 @@
 #from .driver_utils import Utilities
 #from .element_finder import Finder
 #from .scraping_utilities import Scraping_utilities
-from .keyword import scrap_keyword
-from .profile import scrap_profile
-from .topic import scrap_topic
+from .keyword import scrape_keyword
+from .profile import scrape_profile
+from .topic import scrape_topic
 from .keyword_api import scrape_keyword_with_api
 from .profile_details import get_profile_details
-#__all__ = ["Initializer",
+from .topic_api import scrape_topic_with_api
+# __all__ = ["Initializer",
 #           "Utilities", "Finder",
 #           "Scraping_utilities","scrap_profile","scrap_keyword"]
-__all__ = ["scrap_profile", "scrap_keyword",
-           "scrap_topic", "scrape_keyword_with_api", "get_profile_details"]
+__all__ = ["scrape_profile", "scrape_keyword",
+           "scrape_topic", "scrape_keyword_with_api", "get_profile_details", "scrape_topic_with_api"]
