@@ -2,7 +2,7 @@
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.common.by import By
-from selenium.common.exceptions import WebDriverException
+from selenium.common.exceptions import WebDriverException, NoSuchElementException
 import time
 from selenium.webdriver.common.keys import Keys
 from random import randint
@@ -16,14 +16,21 @@ ch.setFormatter(format)
 logger.addHandler(ch)
 
 
-
 class Utilities:
-    """this class contains all the method related to driver behaviour,
+    """
+    this class contains all the method related to driver behaviour,
     like scrolling, waiting for element to appear, it contains all static
-    method, which accepts driver instance as a argument"""
+    method, which accepts driver instance as a argument
 
     @staticmethod
-    def __wait_until_tweets_appear(driver):
+    def method_name(parameters):
+    """
+
+    @staticmethod
+    def wait_until_tweets_appear(driver) -> None:
+        """Wait for tweet to appear. Helpful to work with the system facing
+        slow internet connection issues
+        """
         try:
             WebDriverWait(driver, 10).until(EC.presence_of_element_located(
                 (By.CSS_SELECTOR, '[data-testid="tweet"]')))
@@ -32,7 +39,8 @@ class Utilities:
                 "Tweets did not appear!, Try setting headless=False to see what is happening")
 
     @staticmethod
-    def __scroll_down(driver):
+    def scroll_down(driver) -> None:
+        """Helps to scroll down web page"""
         try:
             body = driver.find_element(By.CSS_SELECTOR, 'body')
             for _ in range(randint(1, 3)):
@@ -41,7 +49,7 @@ class Utilities:
             logger.exception("Error at scroll_down method {}".format(ex))
 
     @staticmethod
-    def __wait_until_completion(driver):
+    def wait_until_completion(driver) -> None:
         """waits until the page have completed loading"""
         try:
             state = ""
